@@ -35,6 +35,7 @@
 # Copyright 2023 chantra <chantra@users.noreply.github.com>                    #
 # Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2025 Maja Massarini <2678400+majamassarini@users.noreply.github.com>#
+# Copyright 2025 Matej Focko <mfocko@users.noreply.github.com>                 #
 # Copyright 2025 Neel Malik <41765022+neel-m@users.noreply.github.com>         #
 #                                                                              #
 # This file is part of PyGithub.                                               #
@@ -55,6 +56,8 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
 import base64
 import contextlib
 import io
@@ -64,7 +67,6 @@ import traceback
 import unittest
 import warnings
 from io import BytesIO
-from typing import Optional
 
 import responses
 from requests.structures import CaseInsensitiveDict
@@ -342,17 +344,17 @@ class ReplayingHttpsConnection(ReplayingConnection):
 
 class BasicTestCase(unittest.TestCase):
     recordMode = False
-    tokenAuthMode = False
-    jwtAuthMode = False
+    authMode = "token"
     per_page = Consts.DEFAULT_PER_PAGE
     retry = None
     pool_size = None
-    seconds_between_requests: Optional[float] = None
-    seconds_between_writes: Optional[float] = None
+    seconds_between_requests: float | None = None
+    seconds_between_writes: float | None = None
     replayDataFolder = os.path.join(os.path.dirname(__file__), "ReplayData")
 
     def setUp(self):
         super().setUp()
+        self.__customFilename: str | None = None
         self.__fileName = ""
         self.__file = None
         if (
@@ -365,11 +367,6 @@ class BasicTestCase(unittest.TestCase):
             )
             import GithubCredentials  # type: ignore
 
-            self.login = (
-                github.Auth.Login(GithubCredentials.login, GithubCredentials.password)
-                if GithubCredentials.login and GithubCredentials.password
-                else None
-            )
             self.oauth_token = (
                 github.Auth.Token(GithubCredentials.oauth_token) if GithubCredentials.oauth_token else None
             )
@@ -385,7 +382,6 @@ class BasicTestCase(unittest.TestCase):
                 ReplayingHttpConnection,
                 ReplayingHttpsConnection,
             )
-            self.login = github.Auth.Login("login", "password")
             self.oauth_token = github.Auth.Token("oauth_token")
             self.jwt = github.Auth.AppAuthToken("jwt")
             self.app_auth = github.Auth.AppAuth(123456, APP_PRIVATE_KEY)
@@ -425,14 +421,26 @@ class BasicTestCase(unittest.TestCase):
             warnings.filterwarnings("ignore", category=category, module=module)
             yield
 
+    @contextlib.contextmanager
+    def replayData(self, filename: str):
+        previous = self.__customFilename
+        self.__customFilename = filename
+        try:
+            yield
+        finally:
+            self.__customFilename = previous
+
     def __openFile(self, mode):
-        for _, _, functionName, _ in traceback.extract_stack():
-            if functionName.startswith("test") or functionName == "setUp" or functionName == "tearDown":
-                if functionName != "test":  # because in class Hook(Framework.TestCase), method testTest calls Hook.test
-                    fileName = os.path.join(
-                        self.replayDataFolder,
-                        f"{self.__class__.__name__}.{functionName}.txt",
-                    )
+        fileName = None
+        if self.__customFilename:
+            fileName = self.__customFilename
+        else:
+            for _, _, functionName, _ in traceback.extract_stack():
+                if functionName.startswith("test") or functionName == "setUp" or functionName == "tearDown":
+                    # because in class Hook(Framework.TestCase), method testTest calls Hook.test
+                    if functionName != "test":
+                        fileName = f"{self.__class__.__name__}.{functionName}.txt"
+        fileName = os.path.join(self.replayDataFolder, fileName) if fileName else None
         if fileName != self.__fileName:
             self.__closeReplayFileIfNeeded()
             self.__fileName = fileName
@@ -478,45 +486,29 @@ class TestCase(BasicTestCase):
         self.g = self.get_github(self.retry, self.pool_size)
 
     def get_github(self, retry, pool_size):
-        if self.tokenAuthMode:
-            return github.Github(
-                auth=self.oauth_token,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
-        elif self.jwtAuthMode:
-            return github.Github(
-                auth=self.jwt,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
+        if self.authMode == "token":
+            auth = self.oauth_token
+        elif self.authMode == "jwt":
+            auth = self.jwt
         else:
-            return github.Github(
-                auth=self.login,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
+            raise ValueError(f"Unsupported test auth mode: {self.authMode}")
+
+        return github.Github(
+            auth=auth,
+            per_page=self.per_page,
+            retry=retry,
+            pool_size=pool_size,
+            seconds_between_requests=self.seconds_between_requests,
+            seconds_between_writes=self.seconds_between_writes,
+        )
 
 
 def activateRecordMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
     BasicTestCase.recordMode = True
 
 
-def activateTokenAuthMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
-    BasicTestCase.tokenAuthMode = True
-
-
 def activateJWTAuthMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
-    BasicTestCase.jwtAuthMode = True
+    BasicTestCase.authMode = "jwt"
 
 
 def enableRetry(retry):
